#' ForIT: A package that implements as R functions the INFC-2005 equations estimating single tree volume and phytomass .
#'
#' The ForIT package provides two main functions, estimating respectively individual and summary
#' values, and some accessory functions, facilitating package use and documenting its content
#'
#' @references
#' Tabacchi G., Di Cosmo L., Gasparini P., Morelli S., 2011a. \emph{Stima
#' del volume e della fitomassa delle principali specie forestali italiane.
#' Equazioni di previsione, tavole del volume e tavole della fitomassa arborea
#' epigea. Stima del volume e della fitomassa delle principali specie
#' forestali italiane. Equazioni di previsione, tavole del volume e tavole
#' della fitomassa arborea epigea}. 412 pp.
#'
#' Tabacchi G., Di Cosmo L., Gasparini P., 2011b. \emph{Aboveground tree
#' volume and phytomass prediction equations for forest species in Italy}.
#' European Journal of Forest Research 130: 6 911-934
#'
#' @keywords internal
"_PACKAGE"
